@@ -13,6 +13,7 @@
 # limitations under the License.
 
 
+import bunch
 import six
 
 from shade import exc
@@ -94,7 +95,7 @@ def get_groups_from_server(cloud, server, server_vars):
 
 
 def get_hostvars_from_server(cloud, server, mounts=None):
-    server_vars = obj_to_dict(server)
+    server_vars = server
     server_vars.pop('links', None)
 
     # Fist, add an IP address
@@ -129,13 +130,14 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     server_vars['image'].pop('links', None)
 
     volumes = []
-    try:
-        for volume in cloud.get_volumes(server):
-            # Make things easier to consume elsewhere
-            volume['device'] = volume['attachments'][0]['device']
-            volumes.append(volume)
-    except exc.OpenStackCloudException:
-        pass
+    if cloud.has_service('volumes'):
+        try:
+            for volume in cloud.get_volumes(server):
+                # Make things easier to consume elsewhere
+                volume['device'] = volume['attachments'][0]['device']
+                volumes.append(volume)
+        except exc.OpenStackCloudException:
+            pass
     server_vars['volumes'] = volumes
     if mounts:
         for mount in mounts:
@@ -160,7 +162,7 @@ def obj_to_dict(obj):
     that we can just have a plain dict of all of the values that exist in the
     nova metadata for a server.
     """
-    instance = {}
+    instance = bunch.Bunch()
     for key in dir(obj):
         value = getattr(obj, key)
         if isinstance(value, NON_CALLABLES) and not key.startswith('_'):
@@ -185,8 +187,15 @@ def warlock_to_dict(obj):
     # glanceclient v2 uses warlock to construct its objects. Warlock does
     # deep black magic to attribute look up to support validation things that
     # means we cannot use normal obj_to_dict
-    obj_dict = {}
+    obj_dict = bunch.Bunch()
     for (key, value) in obj.items():
         if isinstance(value, NON_CALLABLES) and not key.startswith('_'):
             obj_dict[key] = value
     return obj_dict
+
+
+def warlock_list_to_dict(list):
+    new_list = []
+    for obj in list:
+        new_list.append(warlock_to_dict(obj))
+    return new_list
