@@ -20,6 +20,17 @@ Fakes used for testing
 """
 
 
+class FakeEndpoint(object):
+    def __init__(self, id, service_id, region, publicurl, internalurl=None,
+                 adminurl=None):
+        self.id = id
+        self.service_id = service_id
+        self.region = region
+        self.publicurl = publicurl
+        self.internalurl = internalurl
+        self.adminurl = adminurl
+
+
 class FakeFlavor(object):
     def __init__(self, id, name):
         self.id = id
@@ -51,6 +62,14 @@ class FakeServer(object):
         self.status = status
 
 
+class FakeService(object):
+    def __init__(self, id, name, type, description=''):
+        self.id = id
+        self.name = name
+        self.type = type
+        self.description = description
+
+
 class FakeUser(object):
     def __init__(self, id, email, name):
         self.id = id
@@ -63,3 +82,18 @@ class FakeVolume(object):
         self.id = id
         self.status = status
         self.display_name = display_name
+
+
+class FakeMachinePort(object):
+    def __init__(self, id, address, node_id):
+        self.id = id
+        self.address = address
+        self.node_id = node_id
+
+
+class FakeSecgroup(object):
+    def __init__(self, id, name, description='', rules=None):
+        self.id = id
+        self.name = name
+        self.description = description
+        self.rules = rules
