@@ -16,7 +16,6 @@ import mock
 import testtools
 import warlock
 
-from shade import exc
 from shade import meta
 
 PRIVATE_V4 = '198.51.100.3'
@@ -27,6 +26,7 @@ class FakeCloud(object):
     region_name = 'test-region'
     name = 'test-name'
     private = False
+    service_val = True
     _unused = "useless"
 
     def get_flavor_name(self, id):
@@ -38,6 +38,9 @@ class FakeCloud(object):
     def get_volumes(self, server):
         return []
 
+    def has_service(self, service_name):
+        return self.service_val
+
 
 class FakeServer(object):
     id = 'test-id-0'
@@ -106,7 +109,8 @@ class TestMeta(testtools.TestCase):
         self.assertEqual(new_list[1]['value'], 1)
 
     def test_basic_hostvars(self):
-        hostvars = meta.get_hostvars_from_server(FakeCloud(), FakeServer())
+        hostvars = meta.get_hostvars_from_server(
+            FakeCloud(), meta.obj_to_dict(FakeServer()))
         self.assertNotIn('links', hostvars)
         self.assertEqual(PRIVATE_V4, hostvars['private_v4'])
         self.assertEqual(PUBLIC_V4, hostvars['public_v4'])
@@ -126,19 +130,22 @@ class TestMeta(testtools.TestCase):
     def test_private_interface_ip(self):
         cloud = FakeCloud()
         cloud.private = True
-        hostvars = meta.get_hostvars_from_server(cloud, FakeServer())
+        hostvars = meta.get_hostvars_from_server(
+            cloud, meta.obj_to_dict(FakeServer()))
         self.assertEqual(PRIVATE_V4, hostvars['interface_ip'])
 
     def test_image_string(self):
         server = FakeServer()
         server.image = 'fake-image-id'
-        hostvars = meta.get_hostvars_from_server(FakeCloud(), server)
+        hostvars = meta.get_hostvars_from_server(
+            FakeCloud(), meta.obj_to_dict(server))
         self.assertEquals('fake-image-id', hostvars['image']['id'])
 
     def test_az(self):
         server = FakeServer()
         server.__dict__['OS-EXT-AZ:availability_zone'] = 'az1'
-        hostvars = meta.get_hostvars_from_server(FakeCloud(), server)
+        hostvars = meta.get_hostvars_from_server(
+            FakeCloud(), meta.obj_to_dict(server))
         self.assertEquals('az1', hostvars['az'])
 
     def test_has_volume(self):
@@ -150,17 +157,16 @@ class TestMeta(testtools.TestCase):
         mock_volume.attachments = [{'device': '/dev/sda0'}]
         mock_volume_dict = meta.obj_to_dict(mock_volume)
         mock_cloud.get_volumes.return_value = [mock_volume_dict]
-        hostvars = meta.get_hostvars_from_server(mock_cloud, FakeServer())
+        hostvars = meta.get_hostvars_from_server(
+            mock_cloud, meta.obj_to_dict(FakeServer()))
         self.assertEquals('volume1', hostvars['volumes'][0]['id'])
         self.assertEquals('/dev/sda0', hostvars['volumes'][0]['device'])
 
     def test_has_no_volume_service(self):
-        mock_cloud = mock.MagicMock()
-
-        def side_effect(*args):
-            raise exc.OpenStackCloudException("No Volumes")
-        mock_cloud.get_volumes.side_effect = side_effect
-        hostvars = meta.get_hostvars_from_server(mock_cloud, FakeServer())
+        fake_cloud = FakeCloud()
+        fake_cloud.service_val = False
+        hostvars = meta.get_hostvars_from_server(
+            fake_cloud, meta.obj_to_dict(FakeServer()))
         self.assertEquals([], hostvars['volumes'])
 
     def test_unknown_volume_exception(self):
@@ -174,7 +180,9 @@ class TestMeta(testtools.TestCase):
         mock_cloud.get_volumes.side_effect = side_effect
         self.assertRaises(
             FakeException,
-            meta.get_hostvars_from_server, mock_cloud, FakeServer())
+            meta.get_hostvars_from_server,
+            mock_cloud,
+            meta.obj_to_dict(FakeServer()))
 
     def test_obj_to_dict(self):
         cloud = FakeCloud()
@@ -184,6 +192,8 @@ class TestMeta(testtools.TestCase):
         self.assertNotIn('_unused', cloud_dict)
         self.assertNotIn('get_flavor_name', cloud_dict)
         self.assertNotIn('server', cloud_dict)
+        self.assertTrue(hasattr(cloud_dict, 'name'))
+        self.assertEquals(cloud_dict.name, cloud_dict['name'])
 
     def test_warlock_to_dict(self):
         schema = {
@@ -201,3 +211,5 @@ class TestMeta(testtools.TestCase):
         test_dict = meta.warlock_to_dict(test_obj)
         self.assertNotIn('_unused', test_dict)
         self.assertEqual('test-image', test_dict['name'])
+        self.assertTrue(hasattr(test_dict, 'name'))
+        self.assertEquals(test_dict.name, test_dict['name'])
