@@ -20,7 +20,10 @@ import testtools
 import shade
 from shade import exc
 from shade import meta
+from shade import _utils
+
 from shade.tests.unit import base
+from shade.tests import fakes
 
 
 class TestShade(base.TestCase):
@@ -36,14 +39,14 @@ class TestShade(base.TestCase):
         el1 = dict(id=100, name='donald')
         el2 = dict(id=200, name='pluto')
         data = [el1, el2]
-        ret = self.cloud._filter_list(data, 'donald', None)
+        ret = _utils._filter_list(data, 'donald', None)
         self.assertEquals([el1], ret)
 
     def test__filter_list_filter(self):
         el1 = dict(id=100, name='donald', other='duck')
         el2 = dict(id=200, name='donald', other='trump')
         data = [el1, el2]
-        ret = self.cloud._filter_list(data, 'donald', {'other': 'duck'})
+        ret = _utils._filter_list(data, 'donald', {'other': 'duck'})
         self.assertEquals([el1], ret)
 
     def test__filter_list_dict1(self):
@@ -54,8 +57,8 @@ class TestShade(base.TestCase):
         el3 = dict(id=300, name='donald', last='ronald mac',
                    other=dict(category='clown'))
         data = [el1, el2, el3]
-        ret = self.cloud._filter_list(data, 'donald',
-                                      {'other': {'category': 'clown'}})
+        ret = _utils._filter_list(
+            data, 'donald', {'other': {'category': 'clown'}})
         self.assertEquals([el3], ret)
 
     def test__filter_list_dict2(self):
@@ -66,12 +69,47 @@ class TestShade(base.TestCase):
         el3 = dict(id=300, name='donald', last='ronald mac',
                    other=dict(category='clown', financial=dict(status='rich')))
         data = [el1, el2, el3]
-        ret = self.cloud._filter_list(data, 'donald',
-                                      {'other': {
-                                          'financial': {'status': 'rich'}
-                                      }})
+        ret = _utils._filter_list(
+            data, 'donald',
+            {'other': {
+                'financial': {'status': 'rich'}
+                }})
         self.assertEquals([el2, el3], ret)
 
+    @mock.patch.object(shade.OpenStackCloud, 'search_images')
+    def test_get_images(self, mock_search):
+        image1 = dict(id='123', name='mickey')
+        mock_search.return_value = [image1]
+        r = self.cloud.get_image('mickey')
+        self.assertIsNotNone(r)
+        self.assertDictEqual(image1, r)
+
+    @mock.patch.object(shade.OpenStackCloud, 'search_images')
+    def test_get_image_not_found(self, mock_search):
+        mock_search.return_value = []
+        r = self.cloud.get_image('doesNotExist')
+        self.assertIsNone(r)
+
+    @mock.patch.object(shade.OpenStackCloud, 'search_servers')
+    def test_get_server(self, mock_search):
+        server1 = dict(id='123', name='mickey')
+        mock_search.return_value = [server1]
+        r = self.cloud.get_server('mickey')
+        self.assertIsNotNone(r)
+        self.assertDictEqual(server1, r)
+
+    @mock.patch.object(shade.OpenStackCloud, 'search_servers')
+    def test_get_server_not_found(self, mock_search):
+        mock_search.return_value = []
+        r = self.cloud.get_server('doesNotExist')
+        self.assertIsNone(r)
+
+    @mock.patch.object(shade.OpenStackCloud, 'nova_client')
+    def test_list_servers_exception(self, mock_client):
+        mock_client.servers.list.side_effect = Exception()
+        self.assertRaises(exc.OpenStackCloudException,
+                          self.cloud.list_servers)
+
     @mock.patch.object(shade.OpenStackCloud, 'search_subnets')
     def test_get_subnet(self, mock_search):
         subnet = dict(id='123', name='mickey')
@@ -297,6 +335,37 @@ class TestShadeOperator(base.TestCase):
     def test_operator_cloud(self):
         self.assertIsInstance(self.cloud, shade.OperatorCloud)
 
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_list_nics(self, mock_client):
+        port1 = fakes.FakeMachinePort(1, "aa:bb:cc:dd", "node1")
+        port2 = fakes.FakeMachinePort(2, "dd:cc:bb:aa", "node2")
+        port_list = [port1, port2]
+        port_dict_list = meta.obj_list_to_dict(port_list)
+
+        mock_client.port.list.return_value = port_list
+        nics = self.cloud.list_nics()
+
+        self.assertTrue(mock_client.port.list.called)
+        self.assertEqual(port_dict_list, nics)
+
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_list_nics_failure(self, mock_client):
+        mock_client.port.list.side_effect = Exception()
+        self.assertRaises(exc.OpenStackCloudException,
+                          self.cloud.list_nics)
+
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_list_nics_for_machine(self, mock_client):
+        mock_client.node.list_ports.return_value = []
+        self.cloud.list_nics_for_machine("123")
+        mock_client.node.list_ports.assert_called_with(node_id="123")
+
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_list_nics_for_machine_failure(self, mock_client):
+        mock_client.node.list_ports.side_effect = Exception()
+        self.assertRaises(exc.OpenStackCloudException,
+                          self.cloud.list_nics_for_machine, None)
+
     @mock.patch.object(shade.OperatorCloud, 'ironic_client')
     def test_patch_machine(self, mock_client):
         node_id = 'node01'
